@@ -14,30 +14,26 @@ import threading
 import time
 import uuid
 from pathlib import Path
-from typing import Callable, Optional, Set, Union
+from typing import Optional, Sequence
 from urllib.error import URLError
 from urllib.request import urlopen
 
-from rich.console import Console, RenderableType
 from rich.text import Text
 
 from . import __version__
+from .app import GlitterApp
 from .config import AppConfig, load_config, resolve_download_dir, save_config
-from .discovery import DiscoveryService, PeerInfo
+from .discovery import PeerInfo
 from .history import (
-    HistoryRecord,
-    append_record,
     clear_history,
     format_timestamp,
     load_records,
-    now_iso,
 )
 from .language import LANGUAGES, MESSAGES, get_message, render_message
 from .transfer import (
     DEFAULT_TRANSFER_PORT,
     FingerprintMismatchError,
     TransferCancelled,
-    TransferService,
     TransferTicket,
 )
 from .security import (
@@ -47,17 +43,16 @@ from .security import (
     serialize_identity_private_key,
 )
 from .trust import TrustedPeerStore
+from .ui import ProgressTracker, TerminalUI, show_message
 from .utils import (
     default_device_name,
-    ensure_download_dir,
     flush_input_buffer,
     format_rate,
     format_size,
+    local_network_addresses,
     seconds_since,
 )
 
-MIN_PROGRESS_RATE_WINDOW = 0.1
-
 AUTO_ACCEPT_MODE_ALIASES = {
     "0": "off",
     "off": "off",
@@ -102,652 +97,6 @@ def normalize_auto_accept_mode(value: Optional[str]) -> Optional[str]:
 REMOTE_VERSION_URL = "https://raw.githubusercontent.com/scarletkc/glitter/refs/heads/main/glitter/__init__.py"
 
 
-class TerminalUI:
-    """Thin wrapper around rich.Console to standardize CLI I/O."""
-
-    def __init__(self, console: Optional[Console] = None) -> None:
-        self._console = console or Console(markup=True, highlight=False, soft_wrap=True)
-        self._lock = threading.Lock()
-        self._last_carriage_width = 0
-
-    def print(self, message: RenderableType = "", *, end: str = "\n") -> None:
-        with self._lock:
-            self._console.print(
-                message,
-                end=end,
-                soft_wrap=True,
-            )
-            try:
-                self._console.file.flush()
-            except Exception:  # noqa: BLE001
-                pass
-            self._last_carriage_width = 0
-
-    def input(self, prompt: RenderableType) -> str:
-        self.flush()
-        self._last_carriage_width = 0
-        return self._console.input(prompt)
-
-    def carriage(self, message: RenderableType, padding: str = "") -> None:
-        with self._lock:
-            with self._console.capture() as capture:
-                self._console.print(message, end="", soft_wrap=True)
-            rendered = capture.get()
-            visible_width = Text.from_ansi(rendered).cell_len
-            padding_text = padding
-            padding_width = len(padding_text)
-            residual = self._last_carriage_width - (visible_width + padding_width)
-            if residual > 0:
-                padding_text += " " * residual
-                padding_width += residual
-            try:
-                self._console.file.write("\r" + rendered + padding_text)
-                self._console.file.flush()
-            except Exception:  # noqa: BLE001
-                pass
-            self._last_carriage_width = visible_width + padding_width
-
-    def blank(self) -> None:
-        self.print()
-
-    def flush(self) -> None:
-        with self._lock:
-            try:
-                self._console.file.flush()
-            except Exception:  # noqa: BLE001
-                pass
-            self._last_carriage_width = 0
-
-
-def show_message(
-    ui: TerminalUI,
-    key: str,
-    language: str,
-    *,
-    tone: Optional[str] = None,
-    **kwargs: object,
-) -> None:
-    """Helper to print a localized message with consistent styling."""
-
-    ui.print(render_message(key, language, tone=tone, **kwargs))
-
-
-class ProgressTracker:
-    """Unifies progress refresh cadence and rate formatting for transfers."""
-
-    def __init__(
-        self,
-        ui: TerminalUI,
-        language: str,
-        *,
-        min_interval: float = 0.1,
-    ) -> None:
-        self._ui = ui
-        self._language = language
-        self._min_interval = min_interval
-        self._start_time: Optional[float] = None
-        self._last_time: Optional[float] = None
-        self._last_bytes = 0
-        self._last_total = 0
-        self._line_width = 0
-        self._progress_shown = False
-
-    @property
-    def last_bytes(self) -> int:
-        return self._last_bytes
-
-    @property
-    def last_total(self) -> int:
-        return self._last_total
-
-    @property
-    def min_interval(self) -> float:
-        return self._min_interval
-
-    def update(self, transferred: int, total: int, *, force: bool = False) -> bool:
-        transferred = max(0, int(transferred))
-        display_total = int(total) if total > 0 else transferred
-        now = time.time()
-        if (
-            not force
-            and self._last_time is not None
-            and transferred == self._last_bytes
-            and display_total == self._last_total
-        ):
-            return False
-        if not force and self._last_time is not None:
-            time_delta = now - self._last_time
-            if time_delta < self._min_interval:
-                return False
-        if self._start_time is None:
-            self._start_time = now
-        start_time = self._start_time
-        elapsed = max(now - start_time, MIN_PROGRESS_RATE_WINDOW)
-        if self._last_time is None or transferred < self._last_bytes:
-            rate = transferred / elapsed if elapsed > 0 else 0.0
-        else:
-            time_delta = max(now - self._last_time, MIN_PROGRESS_RATE_WINDOW)
-            byte_delta = transferred - self._last_bytes
-            rate = byte_delta / time_delta if time_delta > 0 else 0.0
-        if force:
-            rate = transferred / max(elapsed, MIN_PROGRESS_RATE_WINDOW)
-        message = render_message(
-            "progress_line",
-            self._language,
-            transferred=format_size(transferred),
-            total=format_size(display_total),
-            rate=format_rate(rate),
-        )
-        if len(message.plain) > self._line_width:
-            self._line_width = len(message.plain)
-        padding = " " * max(0, self._line_width - len(message.plain))
-        self._ui.carriage(message, padding)
-        self._last_time = now
-        self._last_bytes = transferred
-        self._last_total = display_total
-        self._progress_shown = True
-        return True
-
-    def finish(self) -> None:
-        if self._progress_shown:
-            self._ui.blank()
-
-
-class GlitterApp:
-    """Orchestrates discovery, transfers, and CLI prompts."""
-
-    def __init__(
-        self,
-        device_id: str,
-        device_name: str,
-        language: str,
-        default_download_dir: Optional[Path] = None,
-        transfer_port: Optional[int] = None,
-        debug: bool = False,
-        encryption_enabled: bool = True,
-        identity_public: Optional[bytes] = None,
-        trust_store: Optional[TrustedPeerStore] = None,
-        auto_accept_trusted: Union[bool, str] = False,
-        ui: Optional[TerminalUI] = None,
-    ) -> None:
-        self.device_id = device_id
-        self.device_name = device_name
-        self.language = language
-        self.default_download_dir = self._prepare_download_dir(default_download_dir)
-        self.debug = debug
-        self._encryption_enabled = encryption_enabled
-        self.ui = ui or TerminalUI()
-        self._identity_public = identity_public or b""
-        self._trust_store = trust_store
-        self._manual_peer_ids: dict[str, str] = {}
-        self._manual_peer_lock = threading.Lock()
-        self._auto_accept_mode = "off"
-        self.set_auto_accept_mode(auto_accept_trusted)
-        self._auto_reject_untrusted = False
-
-        if isinstance(transfer_port, int) and 1 <= transfer_port <= 65535:
-            preferred_port = transfer_port
-            allow_fallback = False
-        else:
-            preferred_port = DEFAULT_TRANSFER_PORT
-            allow_fallback = True
-
-        self._preferred_port = preferred_port
-        self._allow_ephemeral_fallback = allow_fallback
-        self._transfer_service = self._create_transfer_service(preferred_port, allow_fallback)
-        self._discovery: Optional[DiscoveryService] = None
-        self._incoming_lock = threading.Lock()
-        self._incoming_counter = 0
-        self._history_lock = threading.Lock()
-
-    def _prepare_download_dir(self, directory: Optional[Path]) -> Path:
-        if directory is None:
-            return ensure_download_dir()
-        try:
-            directory.mkdir(parents=True, exist_ok=True)
-        except OSError:
-            return ensure_download_dir()
-        return directory
-
-    def set_default_download_dir(self, directory: Path) -> Path:
-        directory = directory.expanduser()
-        directory.mkdir(parents=True, exist_ok=True)
-        self.default_download_dir = directory
-        return directory
-
-    def reset_default_download_dir(self) -> Path:
-        self.default_download_dir = ensure_download_dir()
-        return self.default_download_dir
-
-    @property
-    def auto_accept_mode(self) -> str:
-        return self._auto_accept_mode
-
-    @property
-    def auto_accept_trusted(self) -> bool:
-        return self._auto_accept_mode in {"trusted", "all"}
-
-    def set_auto_accept_mode(self, mode: Union[bool, str]) -> None:
-        if isinstance(mode, bool):
-            normalized = "trusted" if mode else "off"
-        elif isinstance(mode, str):
-            normalized = mode.strip().lower()
-        else:
-            normalized = "off"
-        if normalized not in {"off", "trusted", "all"}:
-            normalized = "off"
-        self._auto_accept_mode = normalized
-
-    def set_auto_accept_trusted(self, enabled: bool) -> None:
-        self.set_auto_accept_mode("trusted" if enabled else "off")
-
-    def set_auto_reject_untrusted(self, enabled: bool) -> None:
-        self._auto_reject_untrusted = bool(enabled)
-
-    def _create_transfer_service(self, bind_port: int, allow_fallback: bool) -> TransferService:
-        return TransferService(
-            device_id=self.device_id,
-            device_name=self.device_name,
-            language=self.language,
-            on_new_request=self._handle_incoming_request,
-            on_cancelled_request=self._handle_request_cancelled,
-            bind_port=bind_port,
-            allow_ephemeral_fallback=allow_fallback,
-            encryption_enabled=self._encryption_enabled,
-            identity_public=self._identity_public,
-            trust_store=self._trust_store,
-        )
-
-    @property
-    def transfer_port(self) -> int:
-        return self._transfer_service.port
-
-    @property
-    def allows_ephemeral_fallback(self) -> bool:
-        return self._allow_ephemeral_fallback
-
-    @property
-    def encryption_enabled(self) -> bool:
-        return self._encryption_enabled
-
-    def set_encryption_enabled(self, enabled: bool) -> None:
-        self._encryption_enabled = bool(enabled)
-        self._transfer_service.set_encryption_enabled(self._encryption_enabled)
-
-    def identity_fingerprint(self) -> Optional[str]:
-        return self._transfer_service.get_identity_fingerprint()
-
-    def should_show_local_fingerprint(self, peer: PeerInfo) -> bool:
-        if not self._trust_store:
-            return True
-        peer_id = getattr(peer, "peer_id", None)
-        if not isinstance(peer_id, str) or not peer_id:
-            return True
-        return self._trust_store.get(peer_id) is None
-
-    def cached_peer_id_for_ip(self, ip: str) -> Optional[str]:
-        with self._manual_peer_lock:
-            return self._manual_peer_ids.get(ip)
-
-    def remember_peer_id_for_ip(self, ip: str, peer_id: str) -> None:
-        if not peer_id:
-            return
-        with self._manual_peer_lock:
-            self._manual_peer_ids[ip] = peer_id
-
-    def clear_trusted_fingerprints(self) -> bool:
-        if not self._trust_store:
-            return False
-        return self._trust_store.clear()
-
-    def change_transfer_port(self, new_port: int) -> int:
-        if not (1 <= new_port <= 65535):
-            raise ValueError("invalid port")
-        if new_port == self._transfer_service.port and not self._allow_ephemeral_fallback:
-            return self._transfer_service.port
-
-        self.cancel_pending_requests()
-        old_service = self._transfer_service
-        old_allow_fallback = self._allow_ephemeral_fallback
-        old_preferred = self._preferred_port
-
-        old_service.stop()
-        try:
-            new_service = self._create_transfer_service(new_port, allow_fallback=False)
-            new_service.start()
-        except OSError as exc:
-            try:
-                old_service.start()
-                old_service.update_identity(self.device_name, self.language)
-                if self._discovery:
-                    self._discovery.update_identity(
-                        self.device_name,
-                        self.language,
-                        old_service.port,
-                    )
-            finally:
-                self._transfer_service = old_service
-                self._allow_ephemeral_fallback = old_allow_fallback
-                self._preferred_port = old_preferred
-            raise exc
-
-        new_service.update_identity(self.device_name, self.language)
-        self._transfer_service = new_service
-        self._preferred_port = new_port
-        self._allow_ephemeral_fallback = False
-        if self._discovery:
-            self._discovery.update_identity(
-                self.device_name,
-                self.language,
-                self._transfer_service.port,
-            )
-        return self._transfer_service.port
-
-    def start(self) -> None:
-        self._transfer_service.start()
-        self._transfer_service.update_identity(self.device_name, self.language)
-        self._discovery = DiscoveryService(
-            peer_id=self.device_id,
-            device_name=self.device_name,
-            language=self.language,
-            transfer_port=self._transfer_service.port,
-        )
-        self._discovery.start()
-
-    def stop(self) -> None:
-        try:
-            if self._discovery:
-                self._discovery.stop()
-        except KeyboardInterrupt:
-            pass
-        finally:
-            self._discovery = None
-        try:
-            self._transfer_service.stop()
-        except KeyboardInterrupt:
-            pass
-
-    # Discovery --------------------------------------------------------
-
-    def list_peers(self) -> list[PeerInfo]:
-        if not self._discovery:
-            return []
-        return self._discovery.get_peers()
-
-    # Transfers --------------------------------------------------------
-
-    def send_file(
-        self,
-        peer: PeerInfo,
-        file_path: Path,
-        progress_cb: Optional[Callable[[int, int], None]] = None,
-        cancel_event: Optional[threading.Event] = None,
-    ) -> tuple[str, str, Optional[str]]:
-        return self._transfer_service.send_file(
-            peer.ip,
-            peer.transfer_port,
-            peer.name,
-            file_path,
-            progress_cb=progress_cb,
-            cancel_event=cancel_event,
-        )
-
-    def pending_requests(self) -> list[TransferTicket]:
-        return self._transfer_service.pending_requests()
-
-    def accept_request(self, request_id: str, directory: Path) -> Optional[TransferTicket]:
-        directory = directory.expanduser()
-        directory.mkdir(parents=True, exist_ok=True)
-        return self._transfer_service.accept_request(request_id, directory)
-
-    def decline_request(self, request_id: str) -> bool:
-        return self._transfer_service.decline_request(request_id)
-
-    def cancel_pending_requests(self, status: str = "cancelled") -> None:
-        tickets = self.pending_requests()
-        if not tickets:
-            return
-        for ticket in tickets:
-            if self._transfer_service.decline_request(ticket.request_id):
-                display_name = ticket.filename + ("/" if ticket.content_type == "directory" else "")
-                self.log_history(
-                    direction="receive",
-                    status=status,
-                    filename=display_name,
-                    size=ticket.filesize,
-                    sha256=ticket.expected_hash,
-                    remote_name=ticket.sender_name,
-                    remote_ip=ticket.sender_ip,
-                    source_path=None,
-                    target_path=None,
-                    remote_version=ticket.sender_version,
-                )
-
-    def log_history(
-        self,
-        direction: str,
-        status: str,
-        filename: str,
-        size: int,
-        sha256: Optional[str],
-        remote_name: str,
-        remote_ip: str,
-        source_path: Optional[Path] = None,
-        target_path: Optional[Path] = None,
-        remote_version: Optional[str] = None,
-    ) -> None:
-        record = HistoryRecord(
-            timestamp=now_iso(),
-            direction=direction,
-            status=status,
-            filename=filename,
-            size=size,
-            sha256=sha256,
-            local_device=self.device_name,
-            remote_name=remote_name,
-            remote_ip=remote_ip,
-            source_path=str(source_path) if source_path else None,
-            target_path=str(target_path) if target_path else None,
-            local_version=__version__,
-            remote_version=remote_version,
-        )
-        with self._history_lock:
-            append_record(record)
-
-    # Internal callbacks -----------------------------------------------
-
-    def update_identity(self, device_name: str, language: str) -> None:
-        self.device_name = device_name
-        self.language = language
-        self._transfer_service.update_identity(device_name, language)
-        if self._discovery:
-            self._discovery.update_identity(device_name, language, self._transfer_service.port)
-
-    def _handle_incoming_request(self, ticket: TransferTicket) -> None:
-        with self._incoming_lock:
-            self._incoming_counter += 1
-        display_name = ticket.filename + ("/" if ticket.content_type == "directory" else "")
-        message = render_message(
-            "incoming_notice",
-            self.language,
-            filename=display_name,
-            size=ticket.filesize,
-            name=ticket.sender_name,
-            ip=ticket.sender_ip,
-        )
-        self.ui.blank()
-        self.ui.print(message)
-        self.ui.blank()
-        self.ui.flush()
-        if ticket.sender_version and ticket.sender_version != __version__:
-            self.ui.print(
-                render_message(
-                    "incoming_version_warning",
-                    self.language,
-                    version=ticket.sender_version,
-                    current=__version__,
-                )
-            )
-            self.ui.flush()
-
-        mode = self.auto_accept_mode
-        allow_auto = mode == "all" or (mode == "trusted" and ticket.identity_status == "trusted")
-        if allow_auto:
-            if self._transfer_service.has_active_receiving():
-                self.ui.print(
-                    render_message(
-                        "auto_accept_trusted_busy",
-                        self.language,
-                        filename=display_name,
-                    )
-                )
-                self.ui.flush()
-            else:
-                destination = self.default_download_dir
-                try:
-                    accepted_ticket = self.accept_request(ticket.request_id, destination)
-                except Exception as exc:  # noqa: BLE001
-                    self.ui.print(
-                        render_message(
-                            "auto_accept_trusted_failed",
-                            self.language,
-                            error=str(exc),
-                        )
-                    )
-                    self.ui.flush()
-                else:
-                    if accepted_ticket:
-                        notice_key = (
-                            "auto_accept_trusted_notice"
-                            if ticket.identity_status == "trusted"
-                            else "auto_accept_all_notice"
-                        )
-                        self._run_auto_accept_postprocess(
-                            accepted_ticket,
-                            ticket,
-                            destination,
-                            notice_key,
-                        )
-                        return
-        if (
-            mode == "trusted"
-            and ticket.identity_status != "trusted"
-            and self._auto_reject_untrusted
-        ):
-            self.ui.print(
-                render_message(
-                    "auto_accept_trusted_rejected",
-                    self.language,
-                    name=ticket.sender_name,
-                    ip=ticket.sender_ip,
-                    filename=display_name,
-                )
-            )
-            self.ui.flush()
-            self.decline_request(ticket.request_id)
-        else:
-            show_message(self.ui, "waiting_for_decision", self.language)
-            self.ui.flush()
-
-    def _run_auto_accept_postprocess(
-        self,
-        accepted_ticket: TransferTicket,
-        ticket: TransferTicket,
-        destination: Path,
-        notice_key: str,
-    ) -> None:
-        display_name = ticket.filename + ("/" if ticket.content_type == "directory" else "")
-        self.ui.print(
-            render_message(
-                notice_key,
-                self.language,
-                filename=display_name,
-                name=ticket.sender_name,
-                path=str(destination),
-            )
-        )
-        self.ui.flush()
-
-        def monitor_completion() -> None:
-            while accepted_ticket.status in {"pending", "receiving"}:
-                time.sleep(0.2)
-            if accepted_ticket.status == "completed" and accepted_ticket.saved_path:
-                self.log_history(
-                    direction="receive",
-                    status="completed",
-                    filename=display_name,
-                    size=accepted_ticket.filesize,
-                    sha256=accepted_ticket.expected_hash,
-                    remote_name=accepted_ticket.sender_name,
-                    remote_ip=accepted_ticket.sender_ip,
-                    source_path=None,
-                    target_path=accepted_ticket.saved_path,
-                    remote_version=accepted_ticket.sender_version,
-                )
-                self.ui.print(
-                    render_message(
-                        "receive_done",
-                        self.language,
-                        path=str(accepted_ticket.saved_path),
-                    )
-                )
-            elif accepted_ticket.status == "failed":
-                error_text = accepted_ticket.error or "failed"
-                self.log_history(
-                    direction="receive",
-                    status=error_text,
-                    filename=display_name,
-                    size=accepted_ticket.filesize,
-                    sha256=accepted_ticket.expected_hash,
-                    remote_name=accepted_ticket.sender_name,
-                    remote_ip=accepted_ticket.sender_ip,
-                    source_path=None,
-                    target_path=accepted_ticket.saved_path,
-                    remote_version=accepted_ticket.sender_version,
-                )
-                self.ui.print(
-                    render_message(
-                        "receive_failed",
-                        self.language,
-                        error=error_text,
-                    )
-                )
-            self.ui.flush()
-
-        threading.Thread(target=monitor_completion, name="glitter-auto-accept", daemon=True).start()
-
-    def _handle_request_cancelled(self, ticket: TransferTicket) -> None:
-        display_name = ticket.filename + ("/" if ticket.content_type == "directory" else "")
-        message = render_message(
-            "incoming_cancelled",
-            self.language,
-            filename=display_name,
-            name=ticket.sender_name,
-        )
-        self.ui.blank()
-        self.ui.print(message)
-        self.ui.blank()
-        self.ui.flush()
-        self.log_history(
-            direction="receive",
-            status="cancelled",
-            filename=display_name,
-            size=ticket.filesize,
-            sha256=ticket.expected_hash,
-            remote_name=ticket.sender_name,
-            remote_ip=ticket.sender_ip,
-            source_path=None,
-            target_path=None,
-            remote_version=ticket.sender_version,
-        )
-
-    def incoming_count(self) -> int:
-        with self._incoming_lock:
-            return self._incoming_counter
-
-    def reset_incoming_count(self) -> None:
-        with self._incoming_lock:
-            self._incoming_counter = 0
 
 
 def prompt_language_choice(
@@ -963,6 +312,18 @@ def parse_target_spec(raw: str, default_port: int) -> Optional[dict[str, object]
     }
 
 
+def match_peers_by_name(peers: Sequence[PeerInfo], query: str) -> list[PeerInfo]:
+    """Return peers whose device name matches the query (case-insensitive)."""
+
+    normalized = query.strip().casefold()
+    if not normalized:
+        return []
+    exact_matches = [peer for peer in peers if peer.name.casefold() == normalized]
+    if exact_matches:
+        return exact_matches
+    return [peer for peer in peers if normalized in peer.name.casefold()]
+
+
 def send_file_cli(
     ui: TerminalUI,
     app: GlitterApp,
@@ -974,12 +335,13 @@ def send_file_cli(
 ) -> None:
     peers = app.list_peers()
     default_port = app.transfer_port
+    peer_number_lookup = {peer.peer_id: index for index, peer in enumerate(peers, start=1)}
     if preselected_peer is None:
         if peers:
             list_peers_cli(ui, app, language)
         else:
             show_message(ui, "no_peers", language)
-            show_message(ui, "manual_target_hint", language)
+            show_message(ui, "manual_target_hint_no_peers", language)
         ui.blank()
     else:
         ui.blank()
@@ -999,6 +361,27 @@ def send_file_cli(
                 if 0 <= idx < len(peers):
                     selected_peer = peers[idx]
                     break
+            name_matches = match_peers_by_name(peers, choice)
+            if name_matches:
+                if len(name_matches) == 1:
+                    selected_peer = name_matches[0]
+                    break
+                option_strings = []
+                for candidate in name_matches:
+                    index_label = peer_number_lookup.get(candidate.peer_id)
+                    if index_label is not None:
+                        option_strings.append(f"[{index_label}] {candidate.name} ({candidate.ip})")
+                    else:
+                        option_strings.append(f"{candidate.name} ({candidate.ip})")
+                ui.print(
+                    render_message(
+                        "peer_name_ambiguous",
+                        language,
+                        name=choice,
+                        options=", ".join(option_strings),
+                    )
+                )
+                continue
             manual_target = parse_target_spec(choice, default_port)
             if manual_target:
                 normalized_ip = manual_target.get("normalized_ip")
@@ -1524,6 +907,7 @@ def settings_menu(ui: TerminalUI, app: GlitterApp, config: AppConfig, language:
             f"settings_auto_accept_state_{app.auto_accept_mode}",
             language,
         )
+        local_ips = ", ".join(local_network_addresses())
         ui.print(
             render_message(
                 "settings_header",
@@ -1534,6 +918,7 @@ def settings_menu(ui: TerminalUI, app: GlitterApp, config: AppConfig, language:
                 port=app.transfer_port,
                 encryption=encryption_label,
                 auto_accept=auto_accept_label,
+                ips=local_ips,
             )
         )
         show_message(ui, "settings_options", language)
@@ -1956,6 +1341,7 @@ def run_send_command(target: str, file_path_arg: str) -> int:
     exit_code = 0
     try:
         peers = app.list_peers()
+        peer_number_lookup = {peer.peer_id: index for index, peer in enumerate(peers, start=1)}
         target_info_prefetched: Optional[dict[str, object]] = None
         target_ip_candidate = parse_target_spec(target, app.transfer_port)
         if target_ip_candidate:
@@ -1974,6 +1360,29 @@ def run_send_command(target: str, file_path_arg: str) -> int:
         else:
             selected_peer = None
 
+        if not selected_peer and peers:
+            name_matches = match_peers_by_name(peers, target)
+            if name_matches:
+                if len(name_matches) == 1:
+                    selected_peer = name_matches[0]
+                else:
+                    option_strings = []
+                    for candidate in name_matches:
+                        index_label = peer_number_lookup.get(candidate.peer_id)
+                        if index_label is not None:
+                            option_strings.append(f"[{index_label}] {candidate.name} ({candidate.ip})")
+                        else:
+                            option_strings.append(f"{candidate.name} ({candidate.ip})")
+                    ui.print(
+                        render_message(
+                            "peer_name_ambiguous",
+                            language,
+                            name=target,
+                            options=", ".join(option_strings),
+                        )
+                    )
+                    return 1
+
         if not selected_peer:
             default_port = app.transfer_port
             target_info = target_info_prefetched or parse_target_spec(target, default_port)
@@ -2242,7 +1651,6 @@ def run_receive_command(mode_arg: Optional[str], dir_arg: Optional[str], port_ar
 
     if temp_dir:
         app.set_default_download_dir(temp_dir)
-        ui.print(render_message("receive_dir_set", language, path=str(temp_dir)))
 
     if port_arg:
         try:
@@ -2293,7 +1701,19 @@ def run_receive_command(mode_arg: Optional[str], dir_arg: Optional[str], port_ar
         app.stop()
         return 1
 
-    ui.print(render_message("receive_waiting", language, mode=mode_label))
+    ui.print(render_message("receive_dir_set", language, path=str(app.default_download_dir)))
+
+    local_ips = ", ".join(local_network_addresses())
+    ui.print(
+        render_message(
+            "receive_waiting",
+            language,
+            mode=mode_label,
+            device=app.device_name,
+            port=app.transfer_port,
+            ips=local_ips,
+        )
+    )
 
     try:
         while True:
