@@ -53,7 +53,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "cli_version_output": "Glitter version {version}",
         "cli_help_help": "show this help message and exit",
         "cli_send_help": "Send a file to the specified IP[:port]",
-        "cli_send_target_help": "Target peer ID or IP[:port] / [IPv6]:port",
+        "cli_send_target_help": "Target peer ID/device name or IP[:port] / [IPv6]:port",
         "cli_send_path_help": "Path to the file or directory to send",
         "cli_send_usage": "%(prog)s <target> <path>",
         "cli_peers_help": "List discovered peers on the local network",
@@ -75,11 +75,12 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "menu_pending": " ({count} pending)",
         "prompt_choice": "Choose an option: ",
         "no_peers": "No peers online right now.",
-        "manual_target_hint": "You can enter an IP address (IPv4/IPv6, optional :port).",
+        "manual_target_hint_no_peers": "No peers detected yet. Enter an IP address (IPv4/IPv6, optional :port) to send manually.",
         "peer_entry": "{index}. {name} ({ip}) — last seen {seconds}s ago — v{version}",
         "peer_version_warning": "! Version mismatch detected (remote {version}, local {current}). Transfers may be unreliable; please update.",
-        "prompt_peer_target": "Select peer number or enter IP: ",
-        "invalid_peer_target": "Invalid selection. Enter a valid number or IP address.",
+        "prompt_peer_target": "Select peer number, device name, or enter IP: ",
+        "invalid_peer_target": "Invalid selection. Enter a valid number, device name, or IP address.",
+        "peer_name_ambiguous": "Multiple peers match \"{name}\". Use the list number or refine your input: {options}",
         "invalid_choice": "Invalid choice. Try again.",
         "prompt_file_path": "Enter file or directory path to send: ",
         "file_not_found": "Path not found or not a sendable file/directory.",
@@ -107,6 +108,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "receive_declined": "Declined transfer request.",
         "peer_timeout": "Peer list updated.",
         "goodbye": "Goodbye!",
+        "support_prompt": "Glitter: Enjoy the tool? Drop a star to support the author! → https://github.com/scarletkc/glitter",
         "incoming_notice": "Incoming transfer '{filename}' ({size} bytes) from {name} ({ip}). Handle via option [3].",
         "waiting_for_decision": "Waiting for user decision...",
         "incoming_cancelled": "Sender cancelled the transfer '{filename}' from {name}.",
@@ -127,7 +129,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "history_entry_send": "[SEND] {time} → {name} ({ip}) — {filename} ({size})",
         "history_entry_receive": "[RECV] {time} ← {name} ({ip}) — {filename} ({size}) saved to {path}",
         "history_entry_failed": "[{direction}] {time} with {name} ({ip}) — {filename} failed: {status}",
-        "settings_header": "Settings — language: {language_name} ({language_code}), device: {device}, port: {port}, encryption: {encryption}, auto-accept: {auto_accept}",
+        "settings_header": "Settings — language: {language_name} ({language_code}), device: {device}, port: {port}, encryption: {encryption}, auto-accept: {auto_accept}, local IPs: {ips}",
         "settings_options": "[1] Change language  [2] Change device name  [3] Change transfer port  [4] Change download directory  [5] Clear history  [6] Transfer encryption  [7] Auto-accept incoming transfers  [8] Clear trusted fingerprints  [9] Back",
         "settings_download_dir_prompt": "Enter default receive directory (current: {current}) — press Enter to restore default:",
         "settings_download_dir_updated": "Default receive directory updated: {path}",
@@ -167,9 +169,9 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "auto_accept_trusted_rejected": "Declined untrusted transfer '{filename}' from {name} ({ip}) while running in 'trusted' receive mode.",
         "receive_mode_invalid": "Invalid auto-accept mode '{value}'. Use off, trusted, or all.",
         "receive_mode_off_disabled": "Auto-accept mode is Off. Enable trusted/all mode with running 'glitter receive'.",
-        "receive_dir_set": "Temporary download directory: {path}",
+        "receive_dir_set": "Files will be saved to: {path}",
         "receive_dir_error": "Failed to prepare directory: {error}",
-        "receive_waiting": "Listening for incoming transfers ({mode}). Press Ctrl+C to stop.",
+        "receive_waiting": "Listening for incoming transfers ({mode}). Device: {device} | Port: {port} | Local IPs: {ips}. Press Ctrl+C to stop.",
         "receive_encryption_disabled": "Warning: encryption disabled for this receive session only.",
         "receive_shutdown": "Stopping receive service...",
     },
@@ -213,7 +215,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "cli_version_output": "Glitter 版本 {version}",
         "cli_help_help": "显示此帮助信息并退出",
         "cli_send_help": "发送文件到指定 IP[:端口]",
-        "cli_send_target_help": "目标 Peer ID 或 IP（支持 IPv4/IPv6，可选端口，如 192.168.1.5:45846 或 [fe80::1]:45846）",
+        "cli_send_target_help": "目标 Peer ID、设备名称或 IP（支持 IPv4/IPv6，可选端口，例如 192.168.1.5:45846 或 [fe80::1]:45846）",
         "cli_send_path_help": "要发送的文件或目录路径",
         "cli_send_usage": "%(prog)s <target> <path>",
         "cli_peers_help": "列出当前发现的局域网客户端",
@@ -235,11 +237,12 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "menu_pending": "（{count} 个待处理）",
         "prompt_choice": "请选择操作：",
         "no_peers": "当前没有在线客户端。",
-        "manual_target_hint": "可手动输入 IP 地址（支持 IPv4/IPv6，可选端口）。",
+        "manual_target_hint_no_peers": "尚未发现其他客户端，可直接输入 IP 地址（支持 IPv4/IPv6，可选端口）手动发送。",
         "peer_entry": "{index}. {name}（{ip}）— 最近 {seconds} 秒前在线 — v{version}",
         "peer_version_warning": "! 版本不一致（对方 {version}，本地 {current}），传输可能异常，请尽快更新。",
-        "prompt_peer_target": "请输入客户端编号或 IP 地址：",
-        "invalid_peer_target": "输入无效，请输入正确的编号或 IP 地址。",
+        "prompt_peer_target": "请输入客户端编号、设备名称或 IP 地址：",
+        "invalid_peer_target": "输入无效，请输入正确的编号、设备名称或 IP 地址。",
+        "peer_name_ambiguous": "有多个客户端匹配“{name}”，请使用列表编号或补充更具体的名称：{options}",
         "invalid_choice": "输入无效，请重试。",
         "prompt_file_path": "请输入要发送的文件或目录路径：",
         "file_not_found": "路径不存在或不是可发送的文件/目录。",
@@ -267,6 +270,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "receive_declined": "已拒绝该传输请求。",
         "peer_timeout": "已更新客户端列表。",
         "goodbye": "再见！",
+        "support_prompt": "Glitter：喜欢这个工具吗？给个 Star 支持作者！ → https://github.com/scarletkc/glitter",
         "incoming_notice": "收到来自 {name}（{ip}）的传输“{filename}”（{size} 字节）。请通过操作 [3] 处理。",
         "waiting_for_decision": "等待用户确认...",
         "incoming_cancelled": "对方已取消来自 {name} 的“{filename}”传输。",
@@ -287,7 +291,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "history_entry_send": "【发送】{time} → {name}（{ip}）— {filename}（{size}）",
         "history_entry_receive": "【接收】{time} ← {name}（{ip}）— {filename}（{size}），保存到 {path}",
         "history_entry_failed": "【{direction}】{time} 与 {name}（{ip}）— {filename} 失败：{status}",
-        "settings_header": "设置 — 当前语言：{language_name} ({language_code})，设备名称：{device}，传输端口：{port}，传输加密：{encryption}，自动接收：{auto_accept}",
+        "settings_header": "设置 — 当前语言：{language_name} ({language_code})，设备名称：{device}，传输端口：{port}，传输加密：{encryption}，自动接收：{auto_accept}，本机 IP：{ips}",
         "settings_options": "[1] 更改语言  [2] 更改设备名称  [3] 更改传输端口  [4] 更改默认接收目录  [5] 清空传输记录  [6] 传输加密  [7] 自动接收传入文件  [8] 清空信任指纹  [9] 返回",
         "settings_download_dir_prompt": "请输入默认接收目录（当前：{current}），直接回车恢复默认：",
         "settings_download_dir_updated": "默认接收目录已更新：{path}",
@@ -327,9 +331,9 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "auto_accept_trusted_rejected": "当前为“仅限已信任”模式，已拒绝来自 {name}（{ip}）的传输“{filename}”。",
         "receive_mode_invalid": "自动接收模式“{value}”无效，请输入 off/trusted/all。",
         "receive_mode_off_disabled": "当前自动接收模式为“关闭”。仅允许“仅限已信任”或“全部”使用 `glitter receive`。",
-        "receive_dir_set": "临时保存目录：{path}",
+        "receive_dir_set": "文件将保存到：{path}",
         "receive_dir_error": "无法准备保存目录：{error}",
-        "receive_waiting": "正在监听传入文件（模式：{mode}），按 Ctrl+C 结束。",
+        "receive_waiting": "正在监听传入文件（模式：{mode}）。设备：{device}，端口：{port}，本地 IP：{ips}。按 Ctrl+C 结束。",
         "receive_encryption_disabled": "警告：本次接收会话已关闭加密（仅临时生效）。",
         "receive_shutdown": "正在停止接收服务……",
     },
@@ -380,10 +384,11 @@ MESSAGE_TONES: Dict[str, str] = {
     "settings_clear_confirm": "",
     "settings_trust_clear_confirm": "",
     "settings_encryption_prompt": "",
-    "manual_target_hint": "",
+    "manual_target_hint_no_peers": "",
     "cancel_hint": "",
     "invalid_choice": "",
     "invalid_peer_target": "",
+    "peer_name_ambiguous": "",
     "file_not_found": "",
     "operation_cancelled": "",
     "no_peers": "",
@@ -414,6 +419,7 @@ MESSAGE_TONES: Dict[str, str] = {
     "settings_port_same": "",
     "settings_encryption_updated": "",
     "goodbye": "",
+    "support_prompt": "info",
     "current_version": "",
     "latest_version": "",
     "update_check_failed": "",
